==> Release_C2.0.3.zip: Release C2.0.3/software/storetw/application/DW_SYNONYMS.sql <==
/*******************************************************
Filename		:  DW_SYNONYMS.sql
Release 		:  c2.0.2
SIR			:  1559, 1557
Description		:  Creates synonyms for web procedures.
Author			:  Joseph Wilson
Date			:  11/04/2002
			   06/17/2003 -- added result application pages
			   08/05/2003 -- added new procs since last 1.1 beta
			   08/11/2003 -- added act medium and community sampled-act intent -JW
			   11/10/2003 -- added blob and zip download pages; added JAVA permissions -JW
			   11/14/2003 -- added new JAVA permissions -JW
			   11/17/2003 -- added DW_result_download_zip and DW_station_download_zip -JW
			   01/22/2004 -- SIR 1586 - seperated grants, synonmys, and permissions into 3 scripts -JW
			   07/28/2004 -- added synonmy for DW_STATIONCRITERIA_STN -JW
Comments		:  
**********************************************************/
SPOOL DW_SYNONYMS.LOG
--CONNECT STORETWEB/STORETWEB@STORET.SDC
CREATE SYNONYM DW_BIO_RESULTCRITERIA_GEO FOR STORETW.DW_BIO_RESULTCRITERIA_GEO;
CREATE SYNONYM DW_BIO_RESULTCRITERIA_PROJECT FOR STORETW.DW_BIO_RESULTCRITERIA_PROJECT;
CREATE SYNONYM DW_BIO_RESULTCRITERIA_STATION FOR STORETW.DW_BIO_RESULTCRITERIA_STATION;
CREATE SYNONYM DW_BOTTOM_OF_PAGE FOR STORETW.DW_BOTTOM_OF_PAGE;
CREATE SYNONYM DW_CHAR_ALIAS_POPUP FOR STORETW.DW_CHAR_ALIAS_POPUP;
CREATE SYNONYM DW_COUNTY_POPUP FOR STORETW.DW_COUNTY_POPUP;
CREATE SYNONYM DW_DATE_SELECT FOR STORETW.DW_DATE_SELECT;
CREATE SYNONYM DW_DISPLAY_CALENDAR FOR STORETW.DW_DISPLAY_CALENDAR;
CREATE SYNONYM DW_EXTREF_POPUP FOR STORETW.DW_EXTREF_POPUP;
CREATE SYNONYM DW_GEO_SELECT FOR STORETW.DW_GEO_SELECT;
CREATE SYNONYM DW_HAB_RESULTCRITERIA_GEO FOR STORETW.DW_HAB_RESULTCRITERIA_GEO;
CREATE SYNONYM DW_HAB_RESULTCRITERIA_PROJECT FOR STORETW.DW_HAB_RESULTCRITERIA_PROJECT;
CREATE SYNONYM DW_HAB_RESULTCRITERIA_STATION FOR STORETW.DW_HAB_RESULTCRITERIA_STATION;
CREATE SYNONYM DW_HOME FOR STORETW.DW_HOME;
CREATE SYNONYM DW_HUC_POPUP FOR STORETW.DW_HUC_POPUP;
CREATE SYNONYM DW_PROJECT_SELECT FOR STORETW.DW_PROJECT_SELECT;
CREATE SYNONYM DW_PROJ_POPUP FOR STORETW.DW_PROJ_POPUP;
CREATE SYNONYM DW_RESULTCRITERIA FOR STORETW.DW_RESULTCRITERIA;
CREATE SYNONYM DW_RESULTCRITERIA_GEO FOR STORETW.DW_RESULTCRITERIA_GEO;
CREATE SYNONYM DW_RESULTCRITERIA_PROJECT FOR STORETW.DW_RESULTCRITERIA_PROJECT;
CREATE SYNONYM DW_RESULTCRITERIA_STATION FOR STORETW.DW_RESULTCRITERIA_STATION;
CREATE SYNONYM DW_RESULT_COUNT FOR STORETW.DW_RESULT_COUNT;
CREATE SYNONYM DW_RESULT_DOWNLOAD_CUSTOM FOR STORETW.DW_RESULT_DOWNLOAD_CUSTOM;
CREATE SYNONYM DW_RESULT_HUB_CUSTOM FOR STORETW.DW_RESULT_HUB_CUSTOM;
CREATE SYNONYM DW_STATIONCRITERIA FOR STORETW.DW_STATIONCRITERIA;
CREATE SYNONYM DW_STATION_COUNT FOR STORETW.DW_STATION_COUNT;
CREATE SYNONYM DW_STATION_DOWNLOAD_CUSTOM FOR STORETW.DW_STATION_DOWNLOAD_CUSTOM;
CREATE SYNONYM DW_STATION_HUB_CUSTOM FOR STORETW.DW_STATION_HUB_CUSTOM;
CREATE SYNONYM DW_STATION_POPUP FOR STORETW.DW_STATION_POPUP;
CREATE SYNONYM DW_STATION_SELECT FOR STORETW.DW_STATION_SELECT;
CREATE SYNONYM DW_TOP_OF_PAGE FOR STORETW.DW_TOP_OF_PAGE;
CREATE SYNONYM DW_intent_community_select FOR STORETW.DW_intent_community_select;
CREATE SYNONYM DW_medium_select FOR STORETW.DW_medium_select;
CREATE SYNONYM DW_BLOB_DOWNLOAD FOR STORETW.DW_BLOB_DOWNLOAD;
CREATE SYNONYM DW_RESULT_DOWNLOAD_ZIP FOR STORETW.DW_RESULT_DOWNLOAD_ZIP;
CREATE SYNONYM DW_STATION_DOWNLOAD_ZIP FOR STORETW.DW_STATION_DOWNLOAD_ZIP;
CREATE SYNONYM DW_STATIONCRITERIA_STN FOR STORETW.DW_STATIONCRITERIA_STN;

SPOOL OFF

==> Release_C2_0_5.zip: Release C2.0.5/software/storetw/application/DW_SYNONYMS.sql <==
/*******************************************************
Filename		:  DW_SYNONYMS.sql
Release 		:  c2.0.2, C2.0.5
SIR			:  1559, 1557, 1633
Description		:  Creates synonyms for web procedures.
Author			:  Joseph Wilson
Date			:  11/04/2002
			   06/17/2003 -- added result application pages
			   08/05/2003 -- added new procs since last 1.1 beta
			   08/11/2003 -- added act medium and community sampled-act intent -JW
			   11/10/2003 -- added blob and zip download pages; added JAVA permissions -JW
			   11/14/2003 -- added new JAVA permissions -JW
			   11/17/2003 -- added DW_result_download_zip and DW_station_download_zip -JW
			   01/22/2004 -- SIR 1586 - seperated grants, synonmys, and permissions into 3 scripts -JW
			   07/28/2004 -- added synonmy for DW_STATIONCRITERIA_STN -JW
 			   08/17/2005 -- added dw_batch_download_pickup -GT
Comments		:  
**********************************************************/
SPOOL DW_SYNONYMS.LOG
--CONNECT STORETWEB/STORETWEB@STORET.SDC
CREATE SYNONYM DW_BIO_RESULTCRITERIA_GEO FOR STORETW.DW_BIO_RESULTCRITERIA_GEO;
CREATE SYNONYM DW_BIO_RESULTCRITERIA_PROJECT FOR STORETW.DW_BIO_RESULTCRITERIA_PROJECT;
CREATE SYNONYM DW_BIO_RESULTCRITERIA_STATION FOR STORETW.DW_BIO_RESULTCRITERIA_STATION;
CREATE SYNONYM DW_BOTTOM_OF_PAGE FOR STORETW.DW_BOTTOM_OF_PAGE;
CREATE SYNONYM DW_CHAR_ALIAS_POPUP FOR STORETW.DW_CHAR_ALIAS_POPUP;
CREATE SYNONYM DW_COUNTY_POPUP FOR STORETW.DW_COUNTY_POPUP;
CREATE SYNONYM DW_DATE_SELECT FOR STORETW.DW_DATE_SELECT;
CREATE SYNONYM DW_DISPLAY_CALENDAR FOR STORETW.DW_DISPLAY_CALENDAR;
CREATE SYNONYM DW_EXTREF_POPUP FOR STORETW.DW_EXTREF_POPUP;
CREATE SYNONYM DW_GEO_SELECT FOR STORETW.DW_GEO_SELECT;
CREATE SYNONYM DW_HAB_RESULTCRITERIA_GEO FOR STORETW.DW_HAB_RESULTCRITERIA_GEO;
CREATE SYNONYM DW_HAB_RESULTCRITERIA_PROJECT FOR STORETW.DW_HAB_RESULTCRITERIA_PROJECT;
CREATE SYNONYM DW_HAB_RESULTCRITERIA_STATION FOR STORETW.DW_HAB_RESULTCRITERIA_STATION;
CREATE SYNONYM DW_HOME FOR STORETW.DW_HOME;
CREATE SYNONYM DW_HUC_POPUP FOR STORETW.DW_HUC_POPUP;
CREATE SYNONYM DW_PROJECT_SELECT FOR STORETW.DW_PROJECT_SELECT;
CREATE SYNONYM DW_PROJ_POPUP FOR STORETW.DW_PROJ_POPUP;
CREATE SYNONYM DW_RESULTCRITERIA FOR STORETW.DW_RESULTCRITERIA;
CREATE SYNONYM DW_RESULTCRITERIA_GEO FOR STORETW.DW_RESULTCRITERIA_GEO;
CREATE SYNONYM DW_RESULTCRITERIA_PROJECT FOR STORETW.DW_RESULTCRITERIA_PROJECT;
CREATE SYNONYM DW_RESULTCRITERIA_STATION FOR STORETW.DW_RESULTCRITERIA_STATION;
CREATE SYNONYM DW_RESULT_COUNT FOR STORETW.DW_RESULT_COUNT;
CREATE SYNONYM DW_RESULT_DOWNLOAD_CUSTOM FOR STORETW.DW_RESULT_DOWNLOAD_CUSTOM;
CREATE SYNONYM DW_RESULT_HUB_CUSTOM FOR STORETW.DW_RESULT_HUB_CUSTOM;
CREATE SYNONYM DW_STATIONCRITERIA FOR STORETW.DW_STATIONCRITERIA;
CREATE SYNONYM DW_STATION_COUNT FOR STORETW.DW_STATION_COUNT;
CREATE SYNONYM DW_STATION_DOWNLOAD_CUSTOM FOR STORETW.DW_STATION_DOWNLOAD_CUSTOM;
CREATE SYNONYM DW_STATION_HUB_CUSTOM FOR STORETW.DW_STATION_HUB_CUSTOM;
CREATE SYNONYM DW_STATION_POPUP FOR STORETW.DW_STATION_POPUP;
CREATE SYNONYM DW_STATION_SELECT FOR STORETW.DW_STATION_SELECT;
CREATE SYNONYM DW_TOP_OF_PAGE FOR STORETW.DW_TOP_OF_PAGE;
CREATE SYNONYM DW_intent_community_select FOR STORETW.DW_intent_community_select;
CREATE SYNONYM DW_medium_select FOR STORETW.DW_medium_select;
CREATE SYNONYM DW_BLOB_DOWNLOAD FOR STORETW.DW_BLOB_DOWNLOAD;
CREATE SYNONYM DW_RESULT_DOWNLOAD_ZIP FOR STORETW.DW_RESULT_DOWNLOAD_ZIP;
CREATE SYNONYM DW_STATION_DOWNLOAD_ZIP FOR STORETW.DW_STATION_DOWNLOAD_ZIP;
CREATE SYNONYM DW_STATIONCRITERIA_STN FOR STORETW.DW_STATIONCRITERIA_STN;
CREATE SYNONYM DW_batch_download_pickup FOR STORETW.DW_batch_download_pickup;

SPOOL OFF
